summaryrefslogtreecommitdiffstats
path: root/buildtools/autotools/autoprojectwidget.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
commit48d4a26399959121f33d2bc3bfe51c7827b654fc (patch)
tree5ae5e6e00d3ba330b7b8be9bc097154b6bc739e8 /buildtools/autotools/autoprojectwidget.h
parent7e701ace6592d09e1f2c0cf28c7d6d872d78f4f5 (diff)
downloadtdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.tar.gz
tdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.zip
TQt4 port kdevelop
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdevelop@1236710 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'buildtools/autotools/autoprojectwidget.h')
-rw-r--r--buildtools/autotools/autoprojectwidget.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/buildtools/autotools/autoprojectwidget.h b/buildtools/autotools/autoprojectwidget.h
index ff79ce71..7d21fd55 100644
--- a/buildtools/autotools/autoprojectwidget.h
+++ b/buildtools/autotools/autoprojectwidget.h
@@ -45,9 +45,10 @@ class KListViewItem;
class TQListViewItem;
class MakefileHandler;
-class AutoProjectWidget : public QVBox
+class AutoProjectWidget : public TQVBox
{
Q_OBJECT
+ TQ_OBJECT
friend class RemoveFileDialog;
friend class TargetOptionsDialog; // to access projectDom() via m_part->projectDom()
public:
@@ -132,13 +133,13 @@ public:
SubprojectItem* selectedSubproject();
/**
* Creates a TargetItem instance without a parent item.
*/
TargetItem *createTargetItem( const TQString &name,
const TQString &prefix, const TQString &primary,
bool take = true );
/**
* Creates a FileItem instance without a parent item.
*/
FileItem *createFileItem( const TQString &name, SubprojectItem *subproject );
@@ -202,8 +203,8 @@ public slots:
void slotOverviewSelectionChanged( TQListViewItem *item );
protected:
- void initOverview ( TQWidget* parent );
- void initDetailview ( TQWidget* parent );
+ void initOverview ( TQWidget* tqparent );
+ void initDetailview ( TQWidget* tqparent );
void initActions ();
virtual void focusInEvent( TQFocusEvent *e );
@@ -132,13 +133,13 @@ public:
SubprojectItem* selectedSubproject();
/**
- * Creates a TargetItem instance without a parent item.
+ * Creates a TargetItem instance without a tqparent item.
*/
TargetItem *createTargetItem( const TQString &name,
@@ -132,13 +133,13 @@ public:
bool take = true );
/**
- * Creates a FileItem instance without a parent item.
+ * Creates a FileItem instance without a tqparent item.
*/
FileItem *createFileItem( const TQString &name, SubprojectItem *subproject );